==> twat_task-1.6.0-py3-none-any.whl: twat_task/__main__.py <==
#!/usr/bin/env python3
"""
Video processing task utilities using Prefect for workflow management.

This module provides a set of tasks and flows for processing video files,
including audio extraction and transcription. It uses Prefect for workflow
management and Pydantic for data validation.

Example:
    from twat_task import VideoTranscript
    from pathlib import Path

    # Process a video file
    vt = VideoTranscript(video_path=Path("video.mp4"))
    print("Audio path:", vt.audio_path)
    print("Transcript:", vt.text_transcript)
"""

from functools import cached_property
from pathlib import Path
from typing import Any, Optional, Tuple, cast

from prefect import flow, task
from pydantic import BaseModel, computed_field


@task(retries=2)
def extract_audio_task(video_path: Path, audio_path: Path) -> None:
    """
    Extract audio from video file.

    This task simulates audio extraction from a video file. In a real
    implementation, this would use a library like moviepy or ffmpeg.

    Args:
        video_path: Path to the input video file
        audio_path: Path where the extracted audio should be saved

    Note:
        Currently uses a mock implementation for demonstration.
    """
    print(f"Extracting audio from {video_path} to {audio_path}")

    # Simulate fetching video metadata as JSON
    import json
    import time
    from random import randint

    print("Fetching video metadata...")
    time.sleep(2)  # Simulate API call

    metadata = {
        "duration": randint(60, 3600),
        "codec": "aac",
        "bitrate": f"{randint(128, 320)}kbps",
        "channels": 2,
        "sample_rate": 44100,
    }

    print("Processing audio chunks...")
    chunk_size = metadata["duration"] // 10
    for i in range(10):
        print(f"Processing chunk {i + 1}/10...")
        time.sleep(0.5)  # Simulate processing time

    # Save simulated audio and metadata
    audio_path.write_text(json.dumps(metadata))


@task(retries=2)
def generate_transcript_task(audio_path: Path) -> str:
    """
    Generate transcript from audio file.

    This task simulates speech recognition and transcription. In a real
    implementation, this would use a service like Whisper or Google Speech-to-Text.

    Args:
        audio_path: Path to the input audio file

    Returns:
        str: The generated transcript text

    Note:
        Currently uses a mock implementation for demonstration.
    """
    print(f"Generating transcript from {audio_path}")

    import json
    import time
    from random import choice, randint

    # Simulate loading audio metadata
    metadata = json.loads(audio_path.read_text())

    print("Initializing speech recognition model...")
    time.sleep(1.5)

    # Simulate processing chunks with progress
    duration = metadata["duration"]
    chunk_size = 30  # Process in 30-second chunks
    chunks = duration // chunk_size

    words = [
        "hello",
        "world",
        "this",
        "is",
        "a",
        "test",
        "video",
        "with",
        "some",
        "random",
        "words",
        "being",
        "processed",
    ]

    transcript_parts = []
    for i in range(chunks):
        print(f"Transcribing chunk {i + 1}/{chunks}...")
        time.sleep(0.3)  # Simulate API call and processing
        # Generate some random text
        chunk_text = " ".join(choice(words) for _ in range(randint(5, 15)))
        transcript_parts.append(chunk_text)

    return " ".join(transcript_parts)


@flow
def process_video_flow(video_path: Path) -> Tuple[Path, str]:
    """
    Process a video file to extract audio and generate transcript.

    This flow coordinates the video processing tasks:
    1. Extract audio from video (if not already done)
    2. Generate transcript from the audio

    Args:
        video_path: Path to the input video file

    Returns:
        Tuple[Path, str]: A tuple containing:
            - Path to the extracted audio file
            - Generated transcript text
    """
    audio = video_path.with_suffix(".mp3")
    # Only extract audio if the file does not exist
    if not audio.exists():
        extract_audio_task(video_path, audio)
    transcript = generate_transcript_task(audio)
    return audio, transcript


class VideoTranscript(BaseModel):
    """
    A Pydantic model for managing video transcription.

    This class provides a high-level interface for processing video files
    and accessing their transcripts. It uses Prefect flows for processing
    and Pydantic for data validation.

    Attributes:
        video_path: Path to the input video file
        audio_path: Computed path to the extracted audio file
        text_transcript: Generated transcript text
    """

    video_path: Path

    @computed_field
    @cached_property
    def audio_path(self) -> Path:
        """Get the path to the extracted audio file."""
        # Trigger the Prefect flow to process the video
        audio, _ = process_video_flow(self.video_path)
        return audio

    @computed_field
    @cached_property
    def text_transcript(self) -> str:
        """Get the transcript text."""
        # Ensure audio extraction happens first
        _, transcript = process_video_flow(self.video_path)
        return transcript


# Example usage
if __name__ == "__main__":
    # Assume "video.mp4" exists; audio and transcript will be generated on demand
    vt = VideoTranscript(video_path=Path("video.mp4"))
    print("Audio path:", vt.audio_path)
    print("Transcript:", vt.text_transcript)

==> twat_task-1.6.2-py3-none-any.whl: twat_task/__main__.py <==
#!/usr/bin/env python3
"""
Video processing task utilities using Prefect for workflow management.

This module provides a set of tasks and flows for processing video files,
including audio extraction and transcription. It uses Prefect for workflow
management and Pydantic for data validation.

Example:
    from twat_task import VideoTranscript
    from pathlib import Path

    # Process a video file
    vt = VideoTranscript(video_path=Path("video.mp4"))
    print("Audio path:", vt.audio_path)
    print("Transcript:", vt.text_transcript)
"""

from functools import cached_property
from pathlib import Path

from prefect import flow, task
from pydantic import BaseModel, computed_field


@task(retries=2)
def extract_audio_task(video_path: Path, audio_path: Path) -> None:
    """
    Extract audio from video file.

    This task simulates audio extraction from a video file. In a real
    implementation, this would use a library like moviepy or ffmpeg.

    Args:
        video_path: Path to the input video file
        audio_path: Path where the extracted audio should be saved

    Note:
        Currently uses a mock implementation for demonstration.
    """

    # Simulate fetching video metadata as JSON
    import json
    import time
    from random import randint

    time.sleep(2)  # Simulate API call

    metadata = {
        "duration": randint(60, 3600),
        "codec": "aac",
        "bitrate": f"{randint(128, 320)}kbps",
        "channels": 2,
        "sample_rate": 44100,
    }

    metadata["duration"] // 10
    for _i in range(10):
        time.sleep(0.5)  # Simulate processing time

    # Save simulated audio and metadata
    audio_path.write_text(json.dumps(metadata))


@task(retries=2)
def generate_transcript_task(audio_path: Path) -> str:
    """
    Generate transcript from audio file.

    This task simulates speech recognition and transcription. In a real
    implementation, this would use a service like Whisper or Google Speech-to-Text.

    Args:
        audio_path: Path to the input audio file

    Returns:
        str: The generated transcript text

    Note:
        Currently uses a mock implementation for demonstration.
    """

    import json
    import time
    from random import choice, randint

    # Simulate loading audio metadata
    metadata = json.loads(audio_path.read_text())

    time.sleep(1.5)

    # Simulate processing chunks with progress
    duration = metadata["duration"]
    chunk_size = 30  # Process in 30-second chunks
    chunks = duration // chunk_size

    words = [
        "hello",
        "world",
        "this",
        "is",
        "a",
        "test",
        "video",
        "with",
        "some",
        "random",
        "words",
        "being",
        "processed",
    ]

    transcript_parts = []
    for _i in range(chunks):
        time.sleep(0.3)  # Simulate API call and processing
        # Generate some random text
        chunk_text = " ".join(choice(words) for _ in range(randint(5, 15)))
        transcript_parts.append(chunk_text)

    return " ".join(transcript_parts)


@flow
def process_video_flow(video_path: Path) -> tuple[Path, str]:
    """
    Process a video file to extract audio and generate transcript.

    This flow coordinates the video processing tasks:
    1. Extract audio from video (if not already done)
    2. Generate transcript from the audio

    Args:
        video_path: Path to the input video file

    Returns:
        Tuple[Path, str]: A tuple containing:
            - Path to the extracted audio file
            - Generated transcript text
    """
    audio = video_path.with_suffix(".mp3")
    # Only extract audio if the file does not exist
    if not audio.exists():
        extract_audio_task(video_path, audio)
    transcript = generate_transcript_task(audio)
    return audio, transcript


class VideoTranscript(BaseModel):
    """
    A Pydantic model for managing video transcription.

    This class provides a high-level interface for processing video files
    and accessing their transcripts. It uses Prefect flows for processing
    and Pydantic for data validation.

    Attributes:
        video_path: Path to the input video file
        audio_path: Computed path to the extracted audio file
        text_transcript: Generated transcript text
    """

    video_path: Path

    @computed_field
    @cached_property
    def audio_path(self) -> Path:
        """Get the path to the extracted audio file."""
        # Trigger the Prefect flow to process the video
        audio, _ = process_video_flow(self.video_path)
        return audio

    @computed_field
    @cached_property
    def text_transcript(self) -> str:
        """Get the transcript text."""
        # Ensure audio extraction happens first
        _, transcript = process_video_flow(self.video_path)
        return transcript


# Example usage
if __name__ == "__main__":
    # Assume "video.mp4" exists; audio and transcript will be generated on demand
    vt = VideoTranscript(video_path=Path("video.mp4"))
